==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Form_DataTable.pm <==
package WebGUI::i18n::Dutch::Form_DataTable;
use utf8;
our $I18N = {
  'New Column' => {
    'lastUpdated' => '1251877999',
    'message' => 'Nieuwe kolom'
  },
  'Value' => {
    'lastUpdated' => '1251877990',
    'message' => 'Waarde'
  },
  'add column' => {
    'lastUpdated' => '1225915660',
    'message' => 'Kolom toevoegen'
  },
  'add row' => {
    'lastUpdated' => '1225915645',
    'message' => 'Rij toevoegen'
  },
  'cancel' => {
    'lastUpdated' => '1225915496',
    'message' => 'Annuleren'
  },
  'delete column' => {
    'lastUpdated' => '1226493004',
    'message' => 'Verwijder'
  },
  'delete confirm' => {
    'lastUpdated' => '1225915521',
    'message' => 'Weet u zeker dat u deze rijen wilt verwijderen?'
  },
  'delete rows' => {
    'lastUpdated' => '1225915545',
    'message' => 'Verwijder geselecteerde rijen'
  },
  'edit schema' => {
    'lastUpdated' => '1225915561',
    'message' => 'Bewerk schema'
  },
  'format date' => {
    'lastUpdated' => '1226493011',
    'message' => 'Datum'
  },
  'format email' => {
    'lastUpdated' => '1225915570',
    'message' => 'E-mail'
  },
  'format link' => {
    'lastUpdated' => '1225915578',
    'message' => 'URL'
  },
  'format number' => {
    'lastUpdated' => '1225915587',
    'message' => 'Nummer'
  },
  'format text' => {
    'lastUpdated' => '1225915597',
    'message' => 'Tekst'
  },
  'help' => {
    'lastUpdated' => '1225915607',
    'message' => 'Help'
  },
  'help add row' => {
    'lastUpdated' => '1225915699',
    'message' => 'Door op &quot;Rij toevoegen&quot; te klikken zal een rij aan de onderkant van de tabel toegevoegd worden.'
  },
  'help default sort' => {
    'lastUpdated' => '1225915752',
    'message' => 'Standaard wordt de tabel exact zo gesorteerd als het moment dat deze wordt opgeslagen.'
  },
  'help edit cell' => {
    'lastUpdated' => '1225915822',
    'message' => 'Dubbelklik op een beld om deze te bewerken. Op de tab toets zal het huidige veld opslaan en de volgende openen.'
  },
  'help reorder column' => {
    'lastUpdated' => '1225915844',
    'message' => 'Sleep kolommen om ze te herordenen.'
  },
  'help select row' => {
    'lastUpdated' => '1225915887',
    'message' => 'Klik op een rij om deze te selecteren. Gebruik shift of ctrl toetsen voor het selecteren van meer rijen.'
  },
  'ok' => {
    'lastUpdated' => '1225915895',
    'message' => 'Ok'
  },
  'save' => {
    'lastUpdated' => '1225915904',
    'message' => 'Opslaan'
  },
  'save failure' => {
    'lastUpdated' => '1225915931',
    'message' => 'Opslaan mislukt! Probeer het alstublieft nog een keer.'
  },
  'save success' => {
    'lastUpdated' => '1225915948',
    'message' => 'Tabel succesvol opgeslagen!'
  },
  'topicName' => {
    'lastUpdated' => '1225915960',
    'message' => 'Data-Tabel'
  }
}
;

1;

==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Form_DataTable.pm <==
package WebGUI::i18n::Dutch::Form_DataTable;
use utf8;
our $I18N = {
  'New Column' => {
    'lastUpdated' => '1251877999',
    'message' => 'Nieuwe kolom'
  },
  'Value' => {
    'lastUpdated' => '1251877990',
    'message' => 'Waarde'
  },
  'add column' => {
    'lastUpdated' => '1225915660',
    'message' => 'Kolom toevoegen'
  },
  'add row' => {
    'lastUpdated' => '1225915645',
    'message' => 'Rij toevoegen'
  },
  'cancel' => {
    'lastUpdated' => '1225915496',
    'message' => 'Annuleren'
  },
  'delete column' => {
    'lastUpdated' => '1226493004',
    'message' => 'Verwijder'
  },
  'delete confirm' => {
    'lastUpdated' => '1225915521',
    'message' => 'Weet u zeker dat u deze rijen wilt verwijderen?'
  },
  'delete rows' => {
    'lastUpdated' => '1225915545',
    'message' => 'Verwijder geselecteerde rijen'
  },
  'edit schema' => {
    'lastUpdated' => '1225915561',
    'message' => 'Bewerk schema'
  },
  'format date' => {
    'lastUpdated' => '1226493011',
    'message' => 'Datum'
  },
  'format email' => {
    'lastUpdated' => '1225915570',
    'message' => 'E-mail'
  },
  'format link' => {
    'lastUpdated' => '1225915578',
    'message' => 'URL'
  },
  'format number' => {
    'lastUpdated' => '1225915587',
    'message' => 'Nummer'
  },
  'format text' => {
    'lastUpdated' => '1225915597',
    'message' => 'Tekst'
  },
  'help' => {
    'lastUpdated' => '1225915607',
    'message' => 'Help'
  },
  'help add row' => {
    'lastUpdated' => '1225915699',
    'message' => 'Door op &quot;Rij toevoegen&quot; te klikken zal een rij aan de onderkant van de tabel toegevoegd worden.'
  },
  'help default sort' => {
    'lastUpdated' => '1225915752',
    'message' => 'Standaard wordt de tabel exact zo gesorteerd als het moment dat deze wordt opgeslagen.'
  },
  'help edit cell' => {
    'lastUpdated' => '1290779853',
    'message' => 'Dubbelklik op een veld om deze te bewerken. Op de tab toets zal het huidige veld opslaan en de volgende openen.'
  },
  'help reorder column' => {
    'lastUpdated' => '1225915844',
    'message' => 'Sleep kolommen om ze te herordenen.'
  },
  'help select row' => {
    'lastUpdated' => '1225915887',
    'message' => 'Klik op een rij om deze te selecteren. Gebruik shift of ctrl toetsen voor het selecteren van meer rijen.'
  },
  'ok' => {
    'lastUpdated' => '1225915895',
    'message' => 'Ok'
  },
  'save' => {
    'lastUpdated' => '1225915904',
    'message' => 'Opslaan'
  },
  'save failure' => {
    'lastUpdated' => '1225915931',
    'message' => 'Opslaan mislukt! Probeer het alstublieft nog een keer.'
  },
  'save success' => {
    'lastUpdated' => '1225915948',
    'message' => 'Tabel succesvol opgeslagen!'
  },
  'topicName' => {
    'lastUpdated' => '1225915960',
    'message' => 'Data-Tabel'
  }
}
;

1;
